tlslite.errors.TLSAuthenticationTypeError

Package tlslite :: Module errors :: Class TLSAuthenticationTypeError |
[show private | hide private]
[frames | no frames]

## Class TLSAuthenticationTypeError

         Exception --+
                     |
              TLSError --+
                         |
    TLSAuthenticationError --+
                             |
                            TLSAuthenticationTypeError

The Checker was expecting the other party to authenticate with a different type of certificate chain.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net